@@ -318,7 +318,7 @@ gail_finish_select (GtkWidget *widget)
               (GTK_IS_MENU_BAR (next_focus_widget) ||
                GTK_IS_MENU_ITEM (next_focus_widget)))
             {
-              gtk_idle_remove (focus_notify_handler);
+              g_source_remove (focus_notify_handler);
               g_object_remove_weak_pointer (G_OBJECT (next_focus_widget), (gpointer *)&next_focus_widget);
               focus_notify_handler = 0;
             }
@@ -498,7 +498,7 @@ gail_focus_notify_when_idle (GtkWidget *widget)
     {
       if (widget)
         {
-          gtk_idle_remove (focus_notify_handler);
+          g_source_remove (focus_notify_handler);
           if (next_focus_widget)
             g_object_remove_weak_pointer (G_OBJECT (next_focus_widget), (gpointer *)&next_focus_widget);
         }
@@ -514,7 +514,7 @@ gail_focus_notify_when_idle (GtkWidget *widget)
       next_focus_widget = widget;
       g_object_add_weak_pointer (G_OBJECT (next_focus_widget), (gpointer *)&next_focus_widget);
     }
-  focus_notify_handler = gtk_idle_add (gail_focus_idle_handler, widget);
+  focus_notify_handler = g_idle_add (gail_focus_idle_handler, widget);
 }
 
 static gboolean
@@ -667,6 +667,7 @@ gail_accessibility_module_init (void)
   GAIL_WIDGET_SET_FACTORY (GNOME_TYPE_CANVAS_RICH_TEXT, gail_canvas_text);
   GAIL_WIDGET_SET_FACTORY (GNOME_TYPE_CANVAS_WIDGET, gail_canvas_widget);
   GAIL_WIDGET_SET_FACTORY (GNOME_TYPE_CANVAS_ITEM, gail_canvas_item);
+  GAIL_WIDGET_SET_FACTORY (GTK_TYPE_OBJECT, gail_object);
 
   atk_focus_tracker_init (gail_focus_tracker_init);
 
