@@ -43,6 +43,7 @@ struct _GailCombo
   GailContainer parent;
 
   gchar         *press_description;
+  guint         action_idle_handler;
 };
 
 GType gail_combo_get_type (void);
@@ -52,7 +53,7 @@ struct _GailComboClass
   GailContainerClass parent_class;
 };
 
-GtkAccessible *gail_combo_new(GtkWidget *widget);
+AtkObject* gail_combo_new (GtkWidget *widget);
 
 #ifdef __cplusplus
 }
